@@ -1,10 +1,10 @@
 use strictures 2;
-package OpenAPI::Modern; # git description: v0.123-7-g3ac7d3ef
+package OpenAPI::Modern; # git description: v0.124-2-g55600338
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate HTTP requests and responses against an OpenAPI v3.0, v3.1 or v3.2 document
 # KEYWORDS: validation evaluation JSON Schema OpenAPI v3.0 v3.1 v3.2 Swagger HTTP request response
 
-our $VERSION = '0.124';
+our $VERSION = '0.125';
 
 use 5.020;
 use utf8;
@@ -777,7 +777,7 @@ sub _validate_path_parameter ($self, $state, $param_obj, $path_captures) {
   return E({ %$state, keyword => 'required' }, 'missing path parameter: %s', $param_obj->{name})
     if not exists $path_captures->{$param_obj->{name}};
 
-  my $data = $path_captures->{$param_obj->{name}}.'';
+  my $data = $path_captures->{$param_obj->{name}};
 
   if (exists $param_obj->{content}) {
     $data = uri_decode($data);
@@ -1641,7 +1641,7 @@ OpenAPI::Modern - Validate HTTP requests and responses against an OpenAPI v3.0,
 
 =head1 VERSION
 
-version 0.124
+version 0.125
 
 =head1 SYNOPSIS
 
